import { Config } from "..";
export declare const enum ClientType {
    koishi = "koishi",
    nonebot = "nonebot"
}
export interface TelemetryEvent {
    name: string;
    localTime: number;
    localUTCTime: number;
    client: {
        type: ClientType;
        machineID: string;
        version: string;
    };
    data?: object;
}
export interface HeartbeatPackage extends TelemetryEvent {
    name: 'ping';
}
export interface OnlineEvent extends TelemetryEvent {
    name: 'online';
    data: {
        isReconnect?: boolean;
        reconnectTimes?: number;
        config: Config;
    };
}
export interface OfflineEvent extends TelemetryEvent {
    name: 'offline';
    data: {
        config: Config;
    };
}
export interface UseCommandEvent extends TelemetryEvent {
    name: 'command';
    data: {
        command: string;
        sessionContent: string;
        platform: string;
        timestamp: number;
    };
}
export interface ExceptionOrErrorEvent extends TelemetryEvent {
    name: 'exc';
    data: {
        command: string;
        sessionContent?: string;
        error: {
            stack?: string;
            message: string;
            name: string;
        };
        platform?: string;
        timestamp?: number;
    };
}
export interface FailedEvent extends TelemetryEvent {
    name: 'failed';
    data: {
        command: string;
        sessionContent: string;
        msg: string;
        platform: string;
        timestamp: number;
    };
}
export interface ServerResponse {
    code: number;
    message: string;
    data?: object;
}
export interface SuccessServerResp extends ServerResponse {
    code: 200;
    message: 'success';
    data?: object;
}
export interface ErrorServerResp extends ServerResponse {
    code: Exclude<number, 200>;
}
